@@ -36,7 +36,7 @@ typedef TQValueVector<TQGuardedPtr<Wire> > WireVector;
 */
 class Connector : public TQObject, public TQCanvasPolygon
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	Connector( Node * startNode, Node * endNode, ICNDocument *_ICNDocument, TQString *id = 0L );
