@@ -28,7 +28,7 @@ typedef TQValueList<TQGuardedPtr<View> > ViewList;
 */
 class Document : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	enum DocumentType
