@@ -21,7 +21,7 @@
 */
 class ECSubcircuit : public Component
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	ECSubcircuit( ICNDocument *icnDocument, bool newItem, const char *id = 0L );
