@@ -25,7 +25,7 @@ class TQTimer;
 */
 class Switch : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 	public:
