@@ -33,7 +33,7 @@ typedef TQMap<TQString, int > StringIntMap;
 */
 class FlowCodeDocument : public ICNDocument
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		FlowCodeDocument( const TQString &caption, KTechlab *ktechlab, const char *name = 0L);
