@@ -58,15 +58,15 @@ ItemEditor::ItemEditor( KateMDI::ToolView * parent )
 	
 	m_defaultsBtn = new TQPushButton( i18n("Defaults"), this);
 	m_defaultsBtn->setEnabled(false);
-	connect(m_defaultsBtn,TQT_SIGNAL(clicked()),propList,TQT_SLOT(slotSetDefaults()));
+	connect(m_defaultsBtn,TQ_SIGNAL(clicked()),propList,TQ_SLOT(slotSetDefaults()));
 	h1Layout->addWidget(m_defaultsBtn);
 	
 	m_mergeBtn = new TQPushButton( i18n("Merge properties"), this );
 	m_mergeBtn->setEnabled(false);
-	connect(m_mergeBtn,TQT_SIGNAL(clicked()),this,TQT_SLOT(mergeProperties()));
+	connect(m_mergeBtn,TQ_SIGNAL(clicked()),this,TQ_SLOT(mergeProperties()));
 	h1Layout->addWidget(m_mergeBtn);
 	
-	// Qt::Orientation widget stuff
+	// TQt::Orientation widget stuff
 	TQHBoxLayout *h2Layout = new TQHBoxLayout( vlayout, 6 );
 	TQSpacerItem *spacer2 = new TQSpacerItem( 1, 1 );
 	h2Layout->addItem(spacer2);
