@@ -25,7 +25,7 @@ class TQTimer;
 */
 class ItemView : public View
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		ItemView( ItemDocument *itemDocument, ViewContainer *viewContainer, uint viewAreaId, const char *name = 0 );
@@ -86,7 +86,7 @@ class ItemView : public View
 */
 class CVBEditor : public TQCanvasView
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
     CVBEditor( TQCanvas *canvas, ItemView *itemView, const char *name );
