@@ -55,7 +55,7 @@ typedef TQMap< TQString, VariableInfo > VariableMap; // Variable name, variable
 */
 class PinSettings : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		enum pin_type
@@ -109,7 +109,7 @@ This is different from PIC info, which includes stuff such as PIC pin names
 */
 class MicroSettings : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
     enum VariableType
