@@ -237,7 +237,7 @@ class ProjectItem : public TQObject, public LinkerOptions, public ProcessingOpti
 */
 class ProjectInfo : public ProjectItem
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
@@ -266,7 +266,7 @@ class ProjectInfo : public ProjectItem
 */
 class ProjectManager : public ItemSelector
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		~ProjectManager();
