@@ -8,12 +8,15 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #define protected public
 #include <kxmlguiclient.h>
 #undef protected
 
 #include "asmformatter.h"
-#include "config.h"
 #include "filemetainfo.h"
 #include "gpsimprocessor.h"
 #include "ktechlab.h"
@@ -60,24 +63,24 @@ TextView::TextView( TextDocument * textDocument, ViewContainer *viewContainer, u
 	m->insertItem( TDEGlobal::iconLoader()->loadIcon( "convert_to_assembly", TDEIcon::Small ), i18n("Assembly"), TextDocument::AssemblyOutput );
 	m->insertItem( TDEGlobal::iconLoader()->loadIcon( "convert_to_hex", TDEIcon::Small ), i18n("Hex"), TextDocument::HexOutput );
 	m->insertItem( TDEGlobal::iconLoader()->loadIcon( "convert_to_pic", TDEIcon::Small ), i18n("PIC (upload)"), TextDocument::PICOutput );
-	connect( m, TQT_SIGNAL(activated(int)), textDocument, TQT_SLOT(slotConvertTo(int)) );
+	connect( m, TQ_SIGNAL(activated(int)), textDocument, TQ_SLOT(slotConvertTo(int)) );
 	
 	m->setItemEnabled( TextDocument::MicrobeOutput, false );
 	//END Convert To * Actions
 	
 	
-	new TDEAction( i18n("Format Assembly Code"), "", TQt::Key_F12, textDocument, TQT_SLOT(formatAssembly()), ac, "format_asm" );
+	new TDEAction( i18n("Format Assembly Code"), "", TQt::Key_F12, textDocument, TQ_SLOT(formatAssembly()), ac, "format_asm" );
 	
 	
 #ifndef NO_GPSIM
 	//BEGIN Debug Actions
-	new TDEAction( i18n("Set &Breakpoint"), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(toggleBreakpoint()), ac, "debug_toggle_breakpoint" );
-	new TDEAction( i18n("Run"), "dbgrun", 0, textDocument, TQT_SLOT(debugRun()), ac, "debug_run" );
-	new TDEAction( i18n("Interrupt"), "media-playback-pause", 0, textDocument, TQT_SLOT(debugInterrupt()), ac, "debug_interrupt" );
-	new TDEAction( i18n("Stop"), "process-stop", 0, textDocument, TQT_SLOT(debugStop()), ac, "debug_stop" );
-	new TDEAction( i18n("Step"), "dbgstep", TQt::CTRL|TQt::ALT|TQt::Key_Right, textDocument, TQT_SLOT(debugStep()), ac, "debug_step" );
-	new TDEAction( i18n("Step Over"), "dbgnext", 0, textDocument, TQT_SLOT(debugStepOver()), ac, "debug_step_over" );
-	new TDEAction( i18n("Step Out"), "dbgstepout", 0, textDocument, TQT_SLOT(debugStepOut()), ac, "debug_step_out" );
+	new TDEAction( i18n("Set &Breakpoint"), 0, 0, this, TQ_SLOT(toggleBreakpoint()), ac, "debug_toggle_breakpoint" );
+	new TDEAction( i18n("Run"), "dbgrun", 0, textDocument, TQ_SLOT(debugRun()), ac, "debug_run" );
+	new TDEAction( i18n("Interrupt"), "media-playback-pause", 0, textDocument, TQ_SLOT(debugInterrupt()), ac, "debug_interrupt" );
+	new TDEAction( i18n("Stop"), "process-stop", 0, textDocument, TQ_SLOT(debugStop()), ac, "debug_stop" );
+	new TDEAction( i18n("Step"), "dbgstep", TQt::CTRL|TQt::ALT|TQt::Key_Right, textDocument, TQ_SLOT(debugStep()), ac, "debug_step" );
+	new TDEAction( i18n("Step Over"), "dbgnext", 0, textDocument, TQ_SLOT(debugStepOver()), ac, "debug_step_over" );
+	new TDEAction( i18n("Step Out"), "dbgstepout", 0, textDocument, TQ_SLOT(debugStepOut()), ac, "debug_step_out" );
 	//END Debug Actions
 #endif
 
@@ -95,8 +98,8 @@ TextView::TextView( TextDocument * textDocument, ViewContainer *viewContainer, u
 	
 	m_view->installPopup( static_cast<TQPopupMenu*>( p_ktechlab->factory()->container( "tdetexteditor_popup", p_ktechlab ) ) );
 		
-	connect( m_view, TQT_SIGNAL(cursorPositionChanged()),	this, TQT_SLOT(slotCursorPositionChanged()) );
-	connect( m_view, TQT_SIGNAL(gotFocus(Kate::View*)),		this, TQT_SLOT(setFocused()) );
+	connect( m_view, TQ_SIGNAL(cursorPositionChanged()),	this, TQ_SLOT(slotCursorPositionChanged()) );
+	connect( m_view, TQ_SIGNAL(gotFocus(Kate::View*)),		this, TQ_SLOT(setFocused()) );
 	
 	m_layout->insertWidget( 0, m_view );
 	
@@ -109,8 +112,8 @@ TextView::TextView( TextDocument * textDocument, ViewContainer *viewContainer, u
 	m_pTextViewLabel->hide();
 	
 	TextViewEventFilter * eventFilter = new TextViewEventFilter( this );
-	connect( eventFilter, TQT_SIGNAL(wordHoveredOver( const TQString&, int, int )), this, TQT_SLOT(slotWordHoveredOver( const TQString&, int, int )) );
-	connect( eventFilter, TQT_SIGNAL(wordUnhovered()), this, TQT_SLOT(slotWordUnhovered()) );
+	connect( eventFilter, TQ_SIGNAL(wordHoveredOver( const TQString&, int, int )), this, TQ_SLOT(slotWordHoveredOver( const TQString&, int, int )) );
+	connect( eventFilter, TQ_SIGNAL(wordUnhovered()), this, TQ_SLOT(slotWordUnhovered()) );
 	
 	TQObject * internalView = m_view->child( 0, "KateViewInternal" );
 	internalView->installEventFilter( eventFilter );
@@ -374,16 +377,16 @@ TextViewEventFilter::TextViewEventFilter( TextView * textView )
 	m_lastLine = m_lastCol = -1;
 	
 	((KTextEditor::TextHintInterface*)textView->kateView()->tqt_cast("KTextEditor::TextHintInterface"))->enableTextHints(0);
-	connect( textView->kateView(), TQT_SIGNAL(needTextHint(int, int, TQString &)), this, TQT_SLOT(slotNeedTextHint( int, int, TQString& )) );
+	connect( textView->kateView(), TQ_SIGNAL(needTextHint(int, int, TQString &)), this, TQ_SLOT(slotNeedTextHint( int, int, TQString& )) );
 	
 	m_pHoverTimer = new TQTimer( this );
-	connect( m_pHoverTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(hoverTimeout()) );
+	connect( m_pHoverTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(hoverTimeout()) );
 	
 	m_pSleepTimer = new TQTimer( this );
-	connect( m_pSleepTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(gotoSleep()) );
+	connect( m_pSleepTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(gotoSleep()) );
 	
 	m_pNoWordTimer = new TQTimer( this );
-	connect( m_pNoWordTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotNoWordTimeout()) );
+	connect( m_pNoWordTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotNoWordTimeout()) );
 }
 
 
